@@ -31,15 +31,21 @@ class Payment:
             'currency': 'ARS',
             'installments': 1,
             'payment_type': 'single',
-            'establishment_name': 'Cadena',  # opcional
+            'establishment_name': '-',  # opcional
             'sub_payments': []
         }
-        if 'site_id' in payment_data:
-            body['site_id'] = payment_data['site_id']
-        if 'sub_payments' in payment_data:
-            body['sub_payments'] = payment_data['sub_payments']
-        if 'payment_type' in payment_data:
-            body['payment_type'] = payment_data['payment_type']
+        additional_information = [
+            'installments',
+            'establishment_name',
+            'site_id',
+            'sub_payments',
+            'payment_type',
+            'site_transaction_id'
+        ]
+        for item in additional_information:
+            if item in payment_data.keys():
+                body[item] = payment_data[item]
+
         r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
         response = r.json()
         response['processor'] = 'decidir'
@@ -51,3 +57,15 @@ class Payment:
     def get(self, payment_id: int):
         r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
         return ok(r.json())
+
+    def search(self,filters:dict) -> dict:
+        # El filter puede ser:
+        # offset
+        # pageSize
+        # siteOperationId
+        # merchantId
+        # dateFrom
+        # dateTo
+        # site
+        r = requests.get(self.url + '/payments',params=filters, headers=self.headers)
+        return r.json()
\ No newline at end of file
